LoggerUi

Struct LoggerUi 

pub struct LoggerUi { /* private fields */ }
The Ui for the Logger. You can use logger_ui() to get a default instance of the LoggerUi.

Implementations

Source

impl LoggerUi

pub fn enable_regex(self, enable: bool) -> Self

Enable or disable the regex search. True by default.

pub fn enable_ctx_menu(self, enable: bool) -> Self

Enable or disable the context menu. True by default.

pub fn show_target(self, enable: bool) -> Self

Enable or disable showing the target in the context menu. True by default.

pub fn include_target(self, enable: bool) -> Self

Enable or disable showing the target in the records. True by default.

pub fn include_level(self, enable: bool) -> Self

Enable or disable showing the level in the records. True by default.

pub fn enable_copy_button(self, enable: bool) -> Self

Enable or disable the copy button. True by default.

pub fn enable_log_count(self, enable: bool) -> Self

Enable or disable the count of how many log messages there are. True by default.

Enable or disable the count of how many log messages there are. True by default.

pub fn enable_max_log_output(self, enable: bool) -> Self

Enable or disable the configurable field for the maximum number of shown log output messages. True by default.

pub fn enable_levels_button(self, enable: bool) -> Self

Enable or disable the button to configure the log levels. True by default.

pub fn enable_categories_button(self, enable: bool) -> Self

Enable or disable the button to configure the log categories. True by default.

pub fn enable_time_button(self, enable: bool) -> Self

Enable or disable the button to configure the time format. True by default.

pub fn warn_color(self, color: Color32) -> Self

Set the color for warning messages.

pub fn error_color(self, color: Color32) -> Self

Set the color for error messages.

pub fn highlight_color(self, color: Color32) -> Self

Set the color for log messages that are neither errors nor warnings.

pub fn log_levels(self, log_levels: [bool; 5]) -> Self

Set which log levels should be enabled. The log_levels are specified as a boolean array where the first element corresponds to the ERROR level and the last one to the TRACE level.

pub fn enable_category(self, category: impl ToString, enable: bool) -> Self

Set which log levels should be enabled.

Panics

Panics if the lock to the logger could not be acquired.

pub fn max_log_length(self, max_length: usize) -> Self

Set the maximum number of log messages that should be retained.

pub fn show(self, ui: &mut Ui)

This draws the Logger UI.