pub struct LoggerUi { /* private fields */ }Expand description
The Ui for the Logger.
You can use logger_ui() to get a default instance of the LoggerUi.
Implementations
Sourceimpl LoggerUi
impl LoggerUi
Sourcepub fn enable_regex(self, enable: bool) -> Self
pub fn enable_regex(self, enable: bool) -> Self
Enable or disable the regex search. True by default.
Enable or disable the context menu. True by default.
Sourcepub fn show_target(self, enable: bool) -> Self
pub fn show_target(self, enable: bool) -> Self
Enable or disable showing the target in the context menu. True by default.
Sourcepub fn include_target(self, enable: bool) -> Self
pub fn include_target(self, enable: bool) -> Self
Enable or disable showing the target in the records. True by default.
Sourcepub fn include_level(self, enable: bool) -> Self
pub fn include_level(self, enable: bool) -> Self
Enable or disable showing the level in the records. True by default.
Enable or disable the copy button. True by default.
Sourcepub fn enable_log_count(self, enable: bool) -> Self
pub fn enable_log_count(self, enable: bool) -> Self
Enable or disable the count of how many log messages there are. True by default.
Sourcepub fn enable_search(self, enable: bool) -> Self
pub fn enable_search(self, enable: bool) -> Self
Enable or disable the count of how many log messages there are. True by default.
Sourcepub fn enable_max_log_output(self, enable: bool) -> Self
pub fn enable_max_log_output(self, enable: bool) -> Self
Enable or disable the configurable field for the maximum number of shown log output messages. True by default.
Enable or disable the button to configure the log levels. True by default.
Enable or disable the button to configure the log categories. True by default.
Enable or disable the button to configure the time format. True by default.
Sourcepub fn warn_color(self, color: Color32) -> Self
pub fn warn_color(self, color: Color32) -> Self
Set the color for warning messages.
Sourcepub fn error_color(self, color: Color32) -> Self
pub fn error_color(self, color: Color32) -> Self
Set the color for error messages.
Sourcepub fn highlight_color(self, color: Color32) -> Self
pub fn highlight_color(self, color: Color32) -> Self
Set the color for log messages that are neither errors nor warnings.
Sourcepub fn log_levels(self, log_levels: [bool; 5]) -> Self
pub fn log_levels(self, log_levels: [bool; 5]) -> Self
Set which log levels should be enabled.
The log_levels are specified as a boolean array where the first element
corresponds to the ERROR level and the last one to the TRACE level.
Sourcepub fn enable_category(self, category: impl ToString, enable: bool) -> Self
pub fn enable_category(self, category: impl ToString, enable: bool) -> Self
Set which log levels should be enabled.
Panics
Panics if the lock to the logger could not be acquired.
Sourcepub fn max_log_length(self, max_length: usize) -> Self
pub fn max_log_length(self, max_length: usize) -> Self
Set the maximum number of log messages that should be retained.